import std.stdio, std.file, std.array, std.algorithm, std.string, std.range, 
       std.process, std.datetime, std.typecons;

void compressImages(string dirname, bool deleting)
{
  if (dirname.startsWith(".\\")) dirname = dirname[2..$];
  auto now = Clock.currTime;
  string today = format("%04d-%02d-%02d", now.year, now.month, now.day);
  if (dirname == today) return writeln("skipping ", dirname, " - today.");
  auto files = dirEntries(dirname, "*.png", SpanMode.shallow, false).array;
  if (files.empty) return;  
  auto outfile = dirname ~ ".avi";
  if (outfile.exists) {
    if (deleting) {
      foreach(fname; files) 
        remove(fname);
      return writeln(dirname, ": ", files.length, " files deleted.");
    } else return writeln(outfile," already exists.");
  }
  sort(files);
  Tuple!(string,string)[] renamings;
  foreach(i, fname; files) {
    string newname = format("%s\\%04d.png", dirname, i);
    if (fname != newname) {
      renamings ~= tuple(cast(string)fname, newname);
      rename(fname, newname);
    }
  }
  auto f = File("conv.avs","wt");
  f.writefln("clip = ImageSource(\"%s\\%%04d.png\", 0, %d, 4)", dirname, files.length - 1);
  f.writeln("clip.LanczosResize(clip.width / 2, clip.height / 2)");
  f.close;
  auto args = cast(char[][])["avs2avi.exe", "conv.avs", outfile, "-c", "scpr"];
  writeln(args);
  execute(args);
  foreach(t; renamings)
    rename(t[1], t[0]);
}

void main(string[] argv)
{
  bool deleting = argv.length > 1 && argv[1]=="delete";
  foreach(d; dirEntries(".", "*", SpanMode.shallow, false).filter!(nm => nm.isDir)) 
    compressImages(d, deleting);  
}
